@@ -1,19 +1,20 @@
 """A lightweight book theme based on the pydata sphinx theme."""
 from pathlib import Path
-from docutils.parsers.rst import directives
+import os
+
 from docutils import nodes
 from sphinx.util import logging
+from bs4 import BeautifulSoup as bs
 from sphinx.util.fileutil import copy_asset
 from sphinx.util.osutil import ensuredir
-from bs4 import BeautifulSoup as bs
-from sass import compile as sass_compile
 
 from .launch import add_hub_urls
 
-__version__ = "0.1.5"
+__version__ = "0.2.3"
 """quantecon-book-theme version"""
 
 SPHINX_LOGGER = logging.getLogger(__name__)
+MESSAGE_CATALOG_NAME = "booktheme"
 
 
 def get_html_theme_path():
@@ -22,27 +23,6 @@ def get_html_theme_path():
     return theme_path
 
 
-def add_static_path(app):
-    static_path = Path(__file__).parent.joinpath("static").absolute()
-    app.config.html_static_path.append(str(static_path))
-
-    # Compile the css file if it's not been compiled already
-    compiled_css_file = static_path / "quantecon-book-theme.css"
-    if not compiled_css_file.exists():
-        source_dir = str(static_path.parent / "scss")
-        output_dir = str(static_path)
-        sass_compile(dirname=(source_dir, output_dir), output_style="compressed")
-
-    # copying plugins
-    if "plugins_list" in app.config.html_theme_options:
-        outdir = app.outdir + "/plugins"
-        ensuredir(outdir)
-        for i, asset in enumerate(app.config.html_theme_options["plugins_list"]):
-            assetname = Path(asset).name
-            copy_asset(app.confdir + "/" + asset, outdir)
-            app.config.html_theme_options["plugins_list"][i] = "plugins/" + assetname
-
-
 def find_url_relative_to_root(pagename, relative_page, path_docs_source):
     """Given the current page (pagename), a relative page to it (relative_page),
     and a path to the docs source, return the path to `relative_page`, but now relative
@@ -65,21 +45,46 @@ def find_url_relative_to_root(pagename, relative_page, path_docs_source):
     return page_rel_root
 
 
+def add_static_path(app):
+    """Ensure CSS/JS is loaded."""
+    static_path = Path(__file__).parent.joinpath("static").absolute()
+    app.config.html_static_path.append(str(static_path))
+
+    # copying plugins
+    if "plugins_list" in app.config.html_theme_options:
+        outdir = app.outdir + "/plugins"
+        ensuredir(outdir)
+        for i, asset in enumerate(app.config.html_theme_options["plugins_list"]):
+            assetname = Path(asset).name
+            copy_asset(app.confdir + "/" + asset, outdir)
+            app.config.html_theme_options["plugins_list"][i] = "plugins/" + assetname
+
+    # Javascript
+    for fname in static_path.iterdir():
+        if ".js" in fname.suffix:
+            app.add_js_file(fname.name)
+
+
 def add_to_context(app, pagename, templatename, context, doctree):
-    def generate_nav_html(
+    """ Functions and variable additions to context."""
+
+    def sbt_generate_nav_html(
         level=1,
         include_item_names=False,
         with_home_page=False,
-        prev_section_numbers=None,
     ):
         # Config stuff
-        config = app.env.config
         if isinstance(with_home_page, str):
             with_home_page = with_home_page.lower() == "true"
 
         # Grab the raw toctree object and structure it so we can manipulate it
-        toc_sphinx = context["toctree"](
-            maxdepth=-1, collapse=False, titles_only=True, includehidden=True
+        toc_sphinx = context["generate_nav_html"](
+            startdepth=level - 1,
+            maxdepth=level + 1,
+            kind="sidebar",
+            collapse=False,
+            titles_only=True,
+            includehidden=True,
         )
         toctree = bs(toc_sphinx, "html.parser")
 
@@ -89,17 +94,17 @@ def add_to_context(app, pagename, templatename, context, doctree):
 
         # Add the master_doc page as the first item if specified
         if with_home_page:
-            # Pull metadata about the master doc
-            master_doc = config["master_doc"]
-            master_doctree = app.env.get_doctree(master_doc)
-            master_url = context["pathto"](master_doc)
-            master_title = list(master_doctree.traverse(nodes.title))[0].astext()
-
+            master_title = master_doctree.traverse(nodes.title)[0].astext()
+            if len(master_title) == 0:
+                raise ValueError(f"Landing page missing a title: {master_doc}")
+            li_class = "toctree-l1"
+            if context["pagename"] == master_doc:
+                li_class += " current"
             # Insert it into our toctree
             ul_home = bs(
                 f"""
-            <ul>
-                <li class="toctree-l1">
+            <ul class="nav bd-sidenav">
+                <li class="{li_class}">
                     <a href="{master_url}" class="reference internal">{master_title}</a>
                 </li>
             </ul>""",
@@ -113,31 +118,12 @@ def add_to_context(app, pagename, templatename, context, doctree):
                 toctree.new_tag("i", attrs={"class": ["fas", "fa-external-link-alt"]})
             )
 
-        # Remove children of all top-level pages unless config says to expand them
-        expand_sections = config.html_theme_options.get("expand_sections", [])
-        if isinstance(expand_sections, str):
-            expand_sections = []
-
-        for li in toctree("li", attrs={"class": "toctree-l1"}):
-            page_rel_root = find_url_relative_to_root(
-                pagename, li.find("a").attrs["href"], app.srcdir
-            )
-            if li.find("ul"):
-                do_collapse = (
-                    "active" not in li.attrs["class"]
-                    and str(page_rel_root) not in expand_sections
-                )
-                if do_collapse:
-                    li.find("ul").decompose()
-
         # Add bootstrap classes for first `ul` items
         for ul in toctree("ul", recursive=False):
             ul.attrs["class"] = ul.attrs.get("class", []) + ["nav", "sidenav_l1"]
 
         return toctree.prettify()
 
-    context["generate_nav_html"] = generate_nav_html
-
     def generate_toc_html():
         """Return the within-page TOC links in HTML."""
 
@@ -178,8 +164,6 @@ def add_to_context(app, pagename, templatename, context, doctree):
             out = ""
         return out
 
-    context["generate_toc_html"] = generate_toc_html
-
     def get_github_src_folder(app):
         if "github_repo" in context:
             github_repo = context["github_repo"]
@@ -190,8 +174,23 @@ def add_to_context(app, pagename, templatename, context, doctree):
                 return "/tree/" + branch + folder
         return ""
 
+    # Pull metadata about the master doc
+    master_doc = app.config["master_doc"]
+    master_doctree = app.env.get_doctree(master_doc)
+    master_url = context["pathto"](master_doc)
+    context["master_url"] = master_url
+
+    # default value is book.tex
+    context["pdf_book_name"] = app.config.latex_documents[0][1].replace(".tex", "")
     context["github_sourcefolder"] = get_github_src_folder(app)
 
+    context["sbt_generate_nav_html"] = sbt_generate_nav_html
+    context["generate_toc_html"] = generate_toc_html
+
+    # check if book pdf folder is present
+    if os.path.isdir(app.outdir + "/_pdf"):
+        context["pdf_book_path"] = "_pdf/" + context["pdf_book_name"] + ".pdf"
+
     # Update the page title because HTML makes it into the page title occasionally
     if pagename in app.env.titles:
         title = app.env.titles[pagename]
@@ -252,52 +251,6 @@ def add_to_context(app, pagename, templatename, context, doctree):
             context[key] = _string_or_bool(context[key])
 
 
-def update_thebe_config(app, env, docnames):
-    """Update thebe configuration with SBT-specific values"""
-    theme_options = env.config.html_theme_options
-    if theme_options.get("launch_buttons", {}).get("thebe") is True:
-        if not hasattr(env.config, "thebe_config"):
-            SPHINX_LOGGER.warning(
-                (
-                    "Thebe is activated but not added to extensions list. "
-                    "Add `sphinx_thebe` to your site's extensions list."
-                )
-            )
-            return
-        # Will be empty if it doesn't exist
-        thebe_config = env.config.thebe_config
-    else:
-        return
-
-    if not theme_options.get("launch_buttons", {}).get("thebe"):
-        return
-
-    # Update the repository branch and URL
-    # Assume that if there's already a thebe_config, then we don't want to over-ride
-    if "repository_url" not in thebe_config:
-        thebe_config["repository_url"] = theme_options.get("repository_url")
-    if "repository_branch" not in thebe_config:
-        branch = theme_options.get("repository_branch")
-        if not branch:
-            # Explicitly check in case branch is ""
-            branch = "master"
-        thebe_config["repository_branch"] = branch
-
-    # Update the selectors to find thebe-enabled cells
-    selector = thebe_config.get("selector", "") + ",.cell"
-    thebe_config["selector"] = selector.lstrip(",")
-
-    selector_input = (
-        thebe_config.get("selector_input", "") + ",.cell_input div.highlight"
-    )
-    thebe_config["selector_input"] = selector_input.lstrip(",")
-
-    selector_output = thebe_config.get("selector_output", "") + ",.cell_output"
-    thebe_config["selector_output"] = selector_output.lstrip(",")
-
-    env.config.thebe_config = thebe_config
-
-
 def _string_or_bool(var):
     if isinstance(var, str):
         return var.lower() == "true"
@@ -307,35 +260,17 @@ def _string_or_bool(var):
         return var is None
 
 
-class Margin(directives.body.Sidebar):
-    """Goes in the margin to the right of the page."""
-
-    optional_arguments = 1
-    required_arguments = 0
-
-    def run(self):
-        """Run the directive."""
-        if not self.arguments:
-            self.arguments = [""]
-        nodes = super().run()
-        nodes[0].attributes["classes"].append("margin")
-
-        # Remove the "title" node if it is empty
-        if not self.arguments:
-            nodes[0].children.pop(0)
-        return nodes
-
-
 def setup(app):
-    app.connect("env-before-read-docs", update_thebe_config)
-
     # Configuration for Juypter Book
-    app.connect("html-page-context", add_hub_urls)
+    app.setup_extension("sphinx_book_theme")
 
+    app.connect("html-page-context", add_hub_urls)
     app.connect("builder-inited", add_static_path)
 
     app.add_html_theme("quantecon_book_theme", get_html_theme_path())
     app.connect("html-page-context", add_to_context)
 
-    app.add_js_file("quantecon-book-theme.js")
-    app.add_directive("margin", Margin, override=True)
+    return {
+        "parallel_read_safe": True,
+        "parallel_write_safe": True,
+    }
